#!/usr/bin/python3
# -*- coding: utf-8 -*-
"""
Generate figures for paper.
@author: Ulf R. Pedersen (www.urp.dk; ulf@urp.dk)
"""

import numpy as np
import matplotlib.pyplot as plt
import pandas as pd

###############################################################################
# Set global parameters
plt.rcParams["figure.figsize"] = [7.6, 5.7] #[6.4, 4.8]
fontsize=18
fontsize_large=22	# Font size
plt.rcParams['font.size'] = fontsize
plt.rcParams['font.family'] = 'Times New Roman'
#plt.rcParams['font.family'] = 'sans-serif'
plt.rcParams['lines.linewidth'] = 1.5
plt.rcParams['axes.linewidth'] = 1.5
plt.rcParams['xtick.top'] = True
plt.rcParams['xtick.direction'] = 'in'
plt.rcParams['xtick.major.size'] = 4
plt.rcParams['xtick.major.width'] = 1.5
plt.rcParams['xtick.minor.width'] = 1.5 
plt.rcParams['ytick.right'] = True
plt.rcParams['ytick.direction'] = 'in'
plt.rcParams['ytick.major.size'] = 4
plt.rcParams['ytick.major.width'] = 1.5
plt.rcParams['ytick.minor.width'] = 1.5 
plt.rcParams['figure.dpi'] = 150
fig, ax = plt.subplots(1,1)


###############################################################################
#  Lattice energies

def fig1a():
    ''' Plot lattice energiles '''
    plt.clf()
    lattice_energies = pd.read_csv("data/lattice_energies.csv")
    lattice_energies_cd = pd.read_csv("data/lattice_energies_cd.csv")
    rho = lattice_energies.get('rho')
    u_fcc = lattice_energies.get('u_fcc')
    u_bcc = lattice_energies.get('u_bcc')
    u_hcp = lattice_energies.get('u_hcp')
    u_cd = lattice_energies_cd.get('u_cd')
    rho_cd = lattice_energies_cd.get('rho')
    #u_fcc_cd = lattice_energies_cd.get('u_fcc')
    plt.plot(rho,u_fcc,'b-D', markevery=60,label='fcc lattice')
    plt.plot(rho,u_bcc,'g-D', markevery=(15,60),label='bcc lattice')
    plt.plot(rho,u_hcp,'r-D', markevery=(30,60),label='hcp lattice')
    plt.plot(rho_cd,u_cd,'y-D', markevery=(45,60),label='cd lattice')
    meanfield=4.0*np.pi*rho
    plt.plot(rho,meanfield,'k--+', markevery=(7,60),label='mean field')
    a=pow(4/rho,1.0/3.0)
    r=np.sqrt(0.5)*a
    firstshell=0.5*12*np.exp(-r)
    plt.plot(rho,firstshell,'k:x', markevery=(22,60),label=r'first shell')
    re=a
    mf2shell=2.0*rho*np.pi*np.exp(-re)*(re*re+2.0*re+2.0)
    plt.plot(rho,mf2shell+firstshell,'k-.3', markevery=(37,60),label=r'first shell + mean field')
	#a=1.0 # 2/3
	#re=a*np.power(rho,-1/3)
	#mfwv=2.0*rho*np.pi*np.exp(-re)*(re*re+2.0*re+2)
	#plt.plot(rho,mfwv,'k-.',label=r'mean field, $a=1$')
    plt.plot(1.74764e-2,0.0947,'bo')
    plt.text(1.7e-2,1e-2,r'$u_{fcc}=u_{bcc}$',fontsize=fontsize_large,color='b')
    plt.yscale('log')
    plt.xscale('log')
    plt.xlabel('Density')
    plt.ylabel(r'$U_0$')
    plt.legend()
    plt.xlim(5e-5,1)
    plt.ylim(1e-12,100)
    plt.text(0.3, 0.1, r'$T=0$', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize)
    plt.text(0.25, 0.92, 'Lattice energy', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize)
    plt.text(0.06, 0.92, '(a)', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize)
    plt.savefig('fig/fig1a.eps',format='eps')

fig1a()


def fig1b():
    '''Plot relatice lattice energy of bcc structure'''
    plt.clf()
    lattice_energies = pd.read_csv("data/lattice_energies.csv")
    rho = lattice_energies.get('rho')
    u_fcc = lattice_energies.get('u_fcc')
    u_bcc = lattice_energies.get('u_bcc')    
    plt.plot(rho,10000*(u_bcc-u_fcc)/u_fcc,'g-',label='fcc')
    plt.plot([1e-6,1],[0,0],'k--')
    plt.xscale('log')
    plt.xlabel('Density')
    plt.ylabel(r'$(u_{bcc}-u_{fcc})/u_{fcc}$ [10$^{-4}$]')
    plt.xlim(5e-5,1)
    plt.ylim(-2,4)
    plt.text(0.06, 0.92, '(b)', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize)
    plt.text(0.9, 0.1, r'$T=0$', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize)
    plt.savefig('fig/fig1b.eps',format='eps')

fig1b()


def fig1c():
    '''Plot relatice lattice energy of hcp structure'''
    plt.clf()
    lattice_energies = pd.read_csv("data/lattice_energies.csv")
    rho = lattice_energies.get('rho')
    u_fcc = lattice_energies.get('u_fcc')
    u_hcp = lattice_energies.get('u_hcp')
    plt.clf()
    plt.plot(rho,(u_hcp-u_fcc)/u_fcc,'r-',label='hcp')
    plt.yscale('log')
    plt.xscale('log')
    plt.xlabel('Density')
    plt.ylabel(r'$(u_{hcp}-u_{fcc})/u_{fcc}$')
    plt.xlim(5e-5,1)
    #plt.text(0.5, 0.92, 'hcp: hexagonal close packed', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize_large)
    plt.text(0.06, 0.92, '(c)', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize)
    plt.text(0.9, 0.1, r'$T=0$', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize)
    plt.savefig('fig/fig1c.eps',format='eps')

fig1c()


def fig1d():
    ''' Plot relatice lattice energy of cd structure '''
    plt.clf()
    lattice_energies = pd.read_csv("data/lattice_energies_cd.csv")
    rho = lattice_energies.get('rho')
    u_fcc = lattice_energies.get('u_fcc')
    u_cd = lattice_energies.get('u_cd')
    plt.plot(rho,(u_cd-u_fcc)/u_fcc,'y-',label='cd')
    plt.yscale('log')
    plt.xscale('log')
    plt.xlabel('Density')
    plt.ylabel(r'$(u_{cd}-u_{fcc})/u_{fcc}$')
    plt.xlim(5e-5,1)
    plt.ylim(1e-3,1e4)
    #plt.text(0.5, 0.92, 'cd: cubic diamond', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize_large)
    plt.text(0.06, 0.92, '(d)', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize)
    plt.text(0.3, 0.1, r'$T=0$', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize)
    plt.savefig('fig/fig1d.eps',format='eps')

fig1d()


def fig2():
    # Polynomial fit to Gibbs energies
    plt.clf()
    lattice_energies_narrow = pd.read_csv("data/lattice_energies_narrow.csv")
    rho = lattice_energies_narrow.get('rho')
    u_fcc = lattice_energies_narrow.get('u_fcc')
    u_bcc = lattice_energies_narrow.get('u_bcc')
    p_fcc = lattice_energies_narrow.get('p_fcc')
    p_bcc = lattice_energies_narrow.get('p_bcc')
    G_fcc = u_fcc+p_fcc/rho
    G_bcc = u_bcc+p_bcc/rho
    x=np.log(np.array(np.float64(p_fcc)))
    y=np.log(np.array(np.float64(G_fcc)))
    p=np.polyfit(x,y,12)
    yfit_fcc=np.polyval(p,x)
    yfit_bcc=np.polyval(p,np.log(np.array(p_bcc)))
    Gfit_fcc=np.exp(yfit_fcc)
    Gfit_bcc=np.exp(yfit_bcc)
    
    # Plot Gibbs free energt
    # plt.plot(ps_fcc,Gfit_fcc,'k--',label="$G_{fit}$, polynomial fit to fcc data")
    pcoex=5.30203e-3*0.5
    #plt.plot(p_bcc,(G_bcc-Gfit_bcc)/G_bcc,'r--',label='$(G_{bcc}-G_{fcc})/G_{fcc}$')
    plt.plot(p_bcc,1e5*(G_bcc-Gfit_bcc)/Gfit_fcc,'r-')
    plt.plot([1e-3,1],[0,0],'k:')
    plt.plot(pcoex,0,'ko',label='$\Delta G(p=%g,T=0)=0$'%pcoex)
    plt.text(3e-3,0.3,r'$p=2.65102\times10^{-3}$')
    #plt.plot([1e-2,2],[0.0,0.0],'k--',label='G=0')
    plt.xlabel('Pressure')
    plt.ylabel(r'Relative chemical potential difference [$10^{-5}$]')
    plt.xlim(1e-3,5e-1)
    plt.ylim(-5.5,4)
    #plt.yscale('log')
    plt.xscale('log')
    plt.text(0.9, 0.1, r'$T=0$', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize)
    plt.text(2e-3,3, r'$(\mu_{bcc}-\mu_{fcc})/\mu_{fcc}$',fontsize=fontsize_large,color='r')
    plt.savefig('fig/fig2.eps',format='eps')
    #plt.show()

fig2()




###############################################################################
#  Pressure in finite temperatire simulations.

def fig3():
    '''Plot bcc pressures for different truccations'''
    plt.clf()
    file="./data/pressures_bcc_T2.2e-3rho0.1.csv"
    df = pd.read_csv(file)
    plt.plot(df.get('rc'),df.get('p'),'ro')
    plt.text(6,0.095,r'0.1186(1)',horizontalalignment='center',verticalalignment='center',fontsize=fontsize)
    plt.arrow(6,0.115,0,-0.01)
    plt.plot([3,8],[0.1191,0.1191],'k:')
    plt.text(2.1,0.1191,r'0.1191(1)',horizontalalignment='center',verticalalignment='center',fontsize=fontsize)
    plt.xlabel('Truncation distance of pair potential')
    plt.ylabel('Pressure')
    plt.xlim(0,8)
    plt.ylim(0,0.13)
    plt.text(0.5,0.06, r'BCC, $T=0.0022$, $\rho=0.1$', horizontalalignment='center', verticalalignment='center', transform=ax.transAxes, fontsize=fontsize_large)
    plt.savefig('./fig/fig3.eps',format='eps')

fig3()




###############################################################################
#  Integration of the Clausius–Clapeyron relation along fcc-bcc line
#


def fig4():
    '''Plot integration along bcc-fcc coexistence'''
    plt.clf()
    Tscl=1e4
    pscl=1e3
    fcc_bcc_T = pd.read_csv("data/fcc_bcc_T.csv")
    fcc_bcc_p = pd.read_csv("data/fcc_bcc_p.csv")
    plt.plot(0,2.65102,'k.',markersize=20, clip_on=False) # $T=0$ coexistence point in Fig. 3
    plt.plot(fcc_bcc_T.get('T')*Tscl,fcc_bcc_T['p']*pscl,'r+',label='Integration along temperature', clip_on=False)
    plt.plot(fcc_bcc_p.get('T')*Tscl,fcc_bcc_p['p']*pscl,'bx',label='Integration along pressure', clip_on=False)
    plt.xlabel(r'Temperature [$10^{-4}$]')
    plt.ylabel(r'Pressure [$10^{-3}$]')
    plt.text(2.5,1.8,"bcc",fontsize=fontsize_large)
    plt.text(1,1,"fcc",fontsize=fontsize_large)
    plt.xlim(0,3.7)
    plt.ylim(0,2.8)
    plt.arrow(0.05,2.7,0.15,-0.08,head_width=0.05, head_length=0.1, fc='k', ec='k')
    plt.arrow(0.3,0.3,0,-0.15,head_width=0.05, head_length=0.1, fc='k', ec='k')
    plt.text(0.3,0.35,"melting", horizontalalignment='center',fontsize=fontsize)
    plt.legend()
    plt.savefig('fig/fig4.eps',format='eps')

fig4()

###############################################################################
# Interface pinning plots

def get_ip_data(variable='p',lattice='bcc',T=5e-4,plot=False,stdprint=False):
    ''' return data from interface pinning simulation along isotherm'''
    filename="./data/%s/T%1.4e.csv"%(lattice,T)
    db = pd.read_csv(filename)
    
    x = db.mu
    y = db.get(variable)
    p = np.polyfit(x,y,1)
    yfit = np.polyval(p,x)
    dy = y-yfit
    dy2=dy*dy
    sse=np.sum(dy2)/(y.size-2)
    error=np.sqrt(sse)

    if plot:
        plt.plot(x,y,'o')
        plt.plot(x,yfit,'k-')
        plt.plot(x,yfit+error,'k--')
        plt.plot(x,yfit-error,'k--')
        #plt.xscale(0)
        plt.show()
    
    estimate = p[1]
    
    if stdprint:
        print(variable,estimate,error)
        print(variable,estimate+error)
        print(variable,estimate-error)
    
    return p[1],error

def get_data_in_tables(lattice='bcc',T=6e-5):
    ''' Print data in Tables 1 and 2. '''
    p,dp = get_ip_data(variable='p',lattice=lattice,T=T)
    vsol,dvsol = get_ip_data(variable='vsol',lattice=lattice,T=T)
    vliq,dvliq = get_ip_data(variable='vliq',lattice=lattice,T=T)
    dv,ddv = get_ip_data(variable='dv',lattice=lattice,T=T)
    ds,dds = get_ip_data(variable='ds',lattice=lattice,T=T)
    return p,vsol,vliq,dv,ds,dp,dvsol,dvliq,ddv,dds

def make_data_tables(lattice='bcc'):
    if lattice=='bcc':
        T=(2.28e-3, 2.2e-3, 2.1e-3, 1.8e-3, 1.5e-3, 1.0e-3, 5.0e-4, 2.0e-4, 1.0e-4, 8.0e-5, 7.0e-5, 6.0e-5, 5.0e-5, 4.0e-5)
    if lattice=='fcc':
        T=(1.0e-4, 8.0e-5, 7.0e-5, 6.0e-5, 5.0e-5, 4.0e-5, 1.0e-5)
    d=np.zeros(shape=(len(T),11))
    d[:,0]=T
    j=0
    for i in T:
        d[j,1:11]=np.array(get_data_in_tables(lattice=lattice,T=i))
        j += 1
    return d

d=make_data_tables(lattice='bcc')
np.savetxt("./data/coexistence_from_ip_bcc.csv", d, delimiter=",",header="T, p, vsol, vliq, dv, ds, dp, dvsol, dvliq, ddv, dds")
d=make_data_tables(lattice='fcc')
np.savetxt("./data/coexistence_from_ip_fcc.csv", d, delimiter=",",header="T, p, vsol, vliq, dv, ds, dp, dvsol, dvliq, ddv, dds")

def fig6a():
    ''' Example of interface pinning data along isotherm '''
    plt.clf()
    T=6e-5
    lattice='bcc'
    filename="data/%s/T%1.4e.csv"%(lattice,T)
    db = pd.read_csv(filename)
    x = db.mu*1e7
    y = db.get('p')*1e6
    p = np.polyfit(x,y,1)
    yfit = np.polyval(p,x)
    dy = y-yfit
    dy2=dy*dy
    sse=np.sum(dy2)/(y.size-2)
    error=np.sqrt(sse)
    x2=[-2,8]
    yfit2=np.polyval(p,x2)
    plt.plot(x,y,'o')
    plt.plot(x2,yfit2,'k-')
    plt.plot(x2,yfit2+error,'k--')
    plt.plot(x2,yfit2-error,'k--')
    plt.plot([0,0],[2.49,2.57],'k:')
    plt.plot(0,  2.5563919601,'kx')
    plt.arrow(0,  2.5563919601,0.8,0,color='k', width=0.0001, head_width=00)
    plt.text(1,2.5563919601,r'$p=2.556(4)\times10^{-6}$',color='k',verticalalignment='center')
    plt.text(0.85, 0.9, r'$T=6\times10^{-5}$', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize)
    plt.text(0.06, 0.82, '(a)', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize)
    plt.xlim(-2,8)
    plt.ylim(2.49,2.57)
    plt.xlabel(r'bcc-liquid chemical potential difference [$10^{-7}$]')
    plt.ylabel(r'Pressure [$10^{-6}$]')
    plt.savefig('./fig/fig6a.eps',format='eps')

fig6a()


to_percent_fmt="%1.0f"
def to_percent(y, position):
    s = str(to_percent_fmt%(100 * y))
    # The percent symbol needs escaping in latex
    if plt.rcParams['text.usetex'] is True:
        return s + r'$\%$'
    else:
        return s + '%'

def fig6b():
    ''' Plot pressure difference near triple point '''
    plt.clf()
    Ts = [4e-5,5e-5,6e-5,7e-5,8e-5]
    pdiff = []
    pdifferr = []
    for T in Ts:
        pbcc,pbcc_err=get_ip_data(variable='p',lattice='bcc',T=T)
        pfcc,pfcc_err=get_ip_data(variable='p',lattice='fcc',T=T)
        pdiff.append((pbcc-pfcc)/pfcc)
        err=(pbcc_err/pbcc+pfcc_err/pfcc)
        pdifferr.append(err)
    x=np.array(Ts)*1e5
    y=np.array(pdiff)
    w=1/np.array(pdifferr)
    p = np.polyfit(x=x,y=y,deg=1,w=w)
    yfit = np.polyval(p,x)
    dy = y-yfit
    dy2=dy*dy
    sse=np.sum(dy2)/(y.size-2)
    yerr=np.sqrt(sse)
    #xerr=yerr*p[1]
    #print('Estimate on y=0:',-p[1]/p[0],xerr)
    from matplotlib.ticker import FuncFormatter
    formatter = FuncFormatter(to_percent)
    plt.gca().yaxis.set_major_formatter(formatter)
    #plt.title('The estimated fcc-bcc-liquid triple point is $T=6.1(4)$x$10^{-5}$')
    plt.errorbar(np.array(Ts)*1e5,pdiff,pdifferr,fmt='bo')
    plt.plot([3,9],[0,0],'k:')
    plt.xlim(3.5,8.5)
    plt.yticks([-0.01,0,0.01])
    plt.xlabel('Temperature [$10^{-5}$]')
    plt.ylabel('Relative coexistence pressure difference')
    plt.text(4.3,0.008,'$(p_{bcc}-p_{fcc})/p_{fcc}$',color='b',fontsize=fontsize)
    plt.text(6.1,0.0005,r'$T_{tp}=5.9(4)\times10^{-5}$',fontsize=fontsize)
    plt.text(0.06, 0.82, '(b)', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize)
    plt.plot(x,yfit,'b--')
    plt.plot(5.9,0,'k.',markersize=15)
    plt.savefig('./fig/fig6b.eps',format='eps')

fig6b()

def fig7a():
    '''Interface-pinning versus Clausius–Clapeyron integration of bcc'''
    plt.clf()
    liquid_bcc = pd.read_csv("./data/liquid_bcc.csv")
    Ts = [4e-5,5e-5,6e-5,7e-5,8e-5,
          1e-4,2e-4,5e-4,
          1e-3,1.5e-3,1.8e-3,2e-3,2.1e-3,2.2e-3,2.28e-3,2.296e-3]
    ps=[]
    for T in Ts:
        p,perr = get_ip_data(variable='p',lattice='bcc',T=T)
        #print(T,p,perr)
        ps.append(p)
    plt.plot(0.12,2.296e-3,'k*',markersize=15)
    plt.plot(ps,Ts,'ro',label='Interface pinning method')
    plt.plot(liquid_bcc['p'],liquid_bcc.get('T'),'g-',label='Clausius–Clapeyron integration')
    plt.text(1e-5,1e-3,'liquid',fontsize=fontsize_large)
    plt.text(2e-2,5e-4,'bcc',fontsize=fontsize_large)
    plt.yscale('log')
    plt.xscale('log')
    plt.xlabel('Pressure')
    plt.ylabel('Temperature')
    plt.xlim(1e-6,1)
    plt.ylim(3e-5,3e-3)
    plt.legend()
    plt.text(0.06, 0.92, '(a)', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize)
    plt.savefig('./fig/fig7a.eps',format='eps')

fig7a()

def fig7b():
    '''Interface-pinning versus Clausius–Clapeyron integration of fcc'''
    plt.clf()
    liquid_fcc = pd.read_csv("./data/liquid_fcc.csv")
    Ts = [1e-5,4e-5,5e-5,6e-5,7e-5,8e-5,5e-5,1e-4]
    ps=[]
    for T in Ts:
        p,perr = get_ip_data(variable='p',lattice='fcc',T=T)
        ps.append(p)
    plt.plot(2.5e-6,5.9e-5,'k.',markersize=25)
    plt.plot(ps,Ts,'ro',label='Interface pinning method')
    plt.plot(liquid_fcc['p'],liquid_fcc.get('T'),'b-',label='Clausius–Clapeyron integration')
    plt.text(5e-9,1e-5,'liquid',fontsize=fontsize_large)
    plt.text(1e-6,3e-6,'fcc',fontsize=fontsize_large)
    plt.yscale('log')
    plt.xscale('log')
    plt.xlabel('Pressure')
    plt.ylabel('Temperature')
    plt.xlim(1e-9,1e-5)
    plt.ylim(1e-7,2e-4)
    plt.text(0.06, 0.92, '(b)', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize)
    plt.legend(loc=4)
    plt.savefig('./fig/fig7b.eps',format='eps')

fig7b()


def fig8a():
    ''' Re-entrence plot 2.3e-3 isotherm '''
    plt.clf()
    df = pd.read_csv("./data/bcc/reentrenceT2.3e-3.csv")
    plt.plot(df['p'],df['mu']*1e5,'bo')
    plt.xlabel('Pressure')
    plt.ylabel(r'bcc-liquid chemical potential difference [$10^{-5}$]')
    plt.xlim(0,0.26)
    plt.ylim(0,7)
    plt.text(0.5,0.6,r'$T=2.3\times10^{-3}$', transform=ax.transAxes,fontsize=fontsize)
    plt.text(0.06, 0.92, '(a)', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize)
    plt.savefig('./fig/fig8a.eps',format='eps')

fig8a()

def fig8b():
    ''' Re-entrence plot estimated coexstence temperature'''
    plt.clf()
    df = pd.read_csv("./data/bcc/reentrenceT2.3e-3.csv")
    plt.plot(0.12,2.296,'k*',markersize=15)
    plt.plot(df['p'],(2.3e-3+df['mu']/df['ds'])*1000,'bo')
    plt.xlabel('Pressure')
    plt.ylabel(r'Estimated coexistence temperature [$10^{-3}$]')
    plt.xlim(0,0.26)
    plt.ylim(2.200,2.30)
    plt.text(0.5,0.08,r'Maximum: $p=0.12(2)$, $T=2.296(3)\times10^{-3}$',horizontalalignment='center',verticalalignment='center',transform=ax.transAxes)
    plt.text(0.06, 0.92, '(b)', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize)
    plt.savefig('./fig/fig8b.eps',format='eps')

fig8b()

###############################################################################
#  Integration of the Clausius–Clapeyron relation along solid-liquid lines

def fig9b():
    ''' rhoT phase diagram '''
    plt.clf()
    fcc_bcc_T = pd.read_csv("./data/fcc_bcc_T.csv")
    fcc_bcc_p = pd.read_csv("./data/fcc_bcc_p.csv")
    fcc_bcc_p = fcc_bcc_p[0:61]
    liquid_bcc = pd.read_csv("./data/liquid_bcc.csv")
    liquid_fcc = pd.read_csv("./data/liquid_fcc.csv")
    plt.plot(1.0/fcc_bcc_T['v_bcc'],fcc_bcc_T.get('T'),'r-',label='bcc-fcc')
    plt.plot(1.0/fcc_bcc_T['v_fcc'],fcc_bcc_T.get('T'),'r-',label='fcc-bcc')
    plt.plot(1.0/fcc_bcc_p['v_bcc'],fcc_bcc_p.get('T'),'r-')
    plt.plot(1.0/fcc_bcc_p['v_fcc'],fcc_bcc_p.get('T'),'r-')
    plt.plot(1.0/liquid_bcc['v_bcc'],liquid_bcc.get('T'),'g-',label='bcc-fluid')
    plt.plot(1.0/liquid_bcc['v_liquid'],liquid_bcc.get('T'),'g-',label='fluid-bcc')
    plt.plot(1.0/liquid_fcc['v_fcc'],liquid_fcc.get('T'),'b-',label='fcc-fluid')
    plt.plot(1.0/liquid_fcc['v_liquid'],liquid_fcc.get('T'),'b-',label='fluid-fcc')
    plt.yscale('log')
    plt.xscale('log')
    plt.xlabel('Density')
    plt.ylabel('Temperature')
    plt.text(1e-3,5e-4,"liquid",fontsize=fontsize_large)
    plt.text(4e-2,3e-4,"bcc",fontsize=fontsize_large)
    plt.text(4e-3,5e-5,"fcc",fontsize=fontsize_large)
    plt.plot(1.575e-3,5.9e-5,'k.',markersize=25)
    vsol,vsol_err = get_ip_data(variable='vsol',lattice='bcc',T=2.2960e-03)
    plt.plot(1/vsol,2.296e-3,'k*',markersize=15)
    #plt.plot(0.12,2.296e-3,'k*')
    #plt.text(0.9, 0.1, 'EXP', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize)
    plt.text(0.06, 0.92, '(b)', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize)
    #plt.legend()
    plt.ylim(5e-6,3e-3)
    plt.xlim(5e-4,2e-1)
    plt.savefig('fig/fig9b.eps',format='eps')

fig9b()


def fig9a():
    ''' Tp phase diagram '''
    plt.clf()
    fcc_bcc_T = pd.read_csv("./data/fcc_bcc_T.csv")
    fcc_bcc_p = pd.read_csv("./data/fcc_bcc_p.csv")
    fcc_bcc_p = fcc_bcc_p[0:61]
    liquid_bcc = pd.read_csv("./data/liquid_bcc.csv")
    liquid_fcc = pd.read_csv("./data/liquid_fcc.csv")
    plt.plot(fcc_bcc_T['p'],fcc_bcc_T.get('T'),'r-',label='bcc-fcc')
    plt.plot(fcc_bcc_p['p'],fcc_bcc_p.get('T'),'r-')
    plt.plot(liquid_bcc['p'],liquid_bcc.get('T'),'g-',label='bcc-fluid')
    plt.plot(liquid_fcc['p'],liquid_fcc.get('T'),'b-',label='fcc-fluid')
    plt.yscale('log')
    plt.xscale('log')
    plt.xlabel('Pressure')
    plt.ylabel('Temperature')
    plt.text(1e-6,5e-4,"liquid",fontsize=fontsize_large)
    plt.text(2e-2,3e-4,"bcc",fontsize=fontsize_large)
    plt.text(5e-5,5e-5,"fcc",fontsize=fontsize_large)
    plt.plot(0.12,2.296e-3,'k*',markersize=15)
    plt.plot(2.5e-6,5.9e-5,'k.',markersize=25)
    plt.text(0.06, 0.92, '(a)', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize)
    #plt.legend()
    plt.ylim(5e-6,3e-3)
    plt.xlim(5e-8,1)
    plt.savefig('fig/fig9a.eps',format='eps')

fig9a()


def fig9d():
    ''' Plot relateive density difference '''
    plt.clf()
    fcc_bcc_T = pd.read_csv("./data/fcc_bcc_T.csv")
    fcc_bcc_p = pd.read_csv("./data/fcc_bcc_p.csv")
    fcc_bcc_p = fcc_bcc_p[0:61]
    liquid_bcc = pd.read_csv("./data/liquid_bcc.csv")
    liquid_fcc = pd.read_csv("./data/liquid_fcc.csv")
    a=1.0/fcc_bcc_T['v_fcc']
    b=1.0/fcc_bcc_T['v_bcc']
    y=(a-b)/b
    plt.plot(fcc_bcc_T['p'],y,'r.',label=r'$(\rho_{fcc}-\rho_{bcc})/\rho_{bcc}$', clip_on=False)
    a=1.0/liquid_bcc['v_bcc']
    b=1.0/liquid_bcc['v_liquid']
    y=(a-b)/b
    plt.plot(liquid_bcc['p'],y,'g.',label=r'$(\rho_{bcc}-\rho_{liquid})/\rho_{liquid}$', clip_on=False)
    a=1.0/liquid_fcc['v_fcc']
    b=1.0/liquid_fcc['v_liquid']
    y=(a-b)/b
    plt.plot(liquid_fcc['p'],y,'b.',label=r'$(\rho_{fcc}-\rho_{liquid})/\rho_{liquid}$')
    plt.legend()
    a=1.0/fcc_bcc_p['v_fcc']
    b=1.0/fcc_bcc_p['v_bcc']
    y=(a-b)/b
    plt.plot(fcc_bcc_p['p'],y,'r.',label=r'$(\rho_{fcc}-\rho_{bcc})/\rho_{bcc}$', clip_on=False)
    plt.plot([5e-8,1],[0,0],'k:')
    plt.xscale('log')
    from matplotlib.ticker import FuncFormatter
    formatter = FuncFormatter(to_percent)
    plt.gca().yaxis.set_major_formatter(formatter)
    plt.xlabel('Pressure')
    plt.ylabel('Relative density change')
    plt.xlim(5e-8,1)
    plt.ylim(-0.1e-2,3.75e-2)
    #plt.ylim(-0.25e-2,3.75e-2)
    plt.text(0.06, 0.92, '(d)', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize)
    plt.savefig('fig/fig9d.eps',format='eps')

to_percent_fmt="%1.1f"
fig9d()


def fig9c():
    # Relative entropy change
    plt.clf()
    fcc_bcc_T = pd.read_csv("./data/fcc_bcc_T.csv")
    fcc_bcc_p = pd.read_csv("./data/fcc_bcc_p.csv")
    fcc_bcc_p = fcc_bcc_p[0:61]
    liquid_bcc = pd.read_csv("./data/liquid_bcc.csv")
    liquid_fcc = pd.read_csv("./data/liquid_fcc.csv")
    slope=fcc_bcc_T['slope0']
    dv=fcc_bcc_T['v_bcc']-fcc_bcc_T['v_fcc']
    ds=slope*dv
    plt.plot(fcc_bcc_T['p'],ds,'r.',label=r'fcc-bcc')
    slope=fcc_bcc_p['slope0']
    dv=fcc_bcc_p['v_bcc']-fcc_bcc_p['v_fcc']
    ds=dv/slope
    plt.plot(fcc_bcc_p['p'],ds,'r.',label=r'fcc-bcc')
    dv=liquid_bcc['v_liquid']-liquid_bcc['v_bcc']
    slope=liquid_bcc['slope0']
    ds=dv/slope
    plt.plot(liquid_bcc['p'],ds,'g.',label=r'bcc-fluid')
    dv=liquid_fcc['v_liquid']-liquid_fcc['v_fcc']
    slope=liquid_fcc['slope0']
    ds=dv/slope
    plt.plot(liquid_fcc['p'],ds,'b.',label=r'fcc-fluid')
    plt.xscale('log')
    plt.xlabel('Pressure')
    plt.ylabel(r'Entropy of transformation')
    plt.xlim(5e-8,1)
    plt.ylim(0,1.1)
    plt.text(5e-6,0.16,'fcc-bcc',color='r',fontsize=fontsize_large)
    plt.text(1e-4,0.78,'bcc-liquid',color='g',fontsize=fontsize_large)
    plt.text(0.8e-7,0.78,'fcc-liquid',color='b',fontsize=fontsize_large)
    plt.text(0.06, 0.92, '(c)', horizontalalignment='center',verticalalignment='center',transform=ax.transAxes, fontsize=fontsize)
    plt.savefig('fig/fig9c.eps',format='eps')

fig9c()

print("Done writing figures.")
